function E = LGmodeM0(l,lam,z0,w0,r,z)
% LGmodeM0 : Laguerre-Gaussian mode (cylindrically symmetry mode)
% l : order
% z0,w0 : waist position and radius
% r,t,z : cylindrical coordinates

% Rayleigh range
zr = pi*w0^2/lam ;

% beam radius
    function w = w(z0,w0,z)
        w = w0 * sqrt( 1 + ( (z-z0)/zr ).^2 ) ;
    end

% radius of curvature of wavefront
    function R = R(z0,z)
        R = (z-z0) .* sqrt( 1 + ( zr./(z-z0) ).^2 ) ;
    end

% q-parameter
    function q = q(z0,z)
        q = 1i*zr + z - z0 ;
    end

% Guoy phase
    function Guoy = Guoy(z0,z)
        Guoy = atan( (z-z0)/zr ) ;
    end

% Laguerre polynomial
    function f = Laguerre(N,x)
        f = hypergeom(-N,1,x) ;
    end


E = sqrt(2/pi) .* exp( 1i * (2*l+1) * Guoy(z0,z) ) ./ w(z0,w0,z) .* Laguerre(l,2*r.^2./w(z0,w0,z).^2) .* exp( - 1i*pi*r.^2./(lam*q(z,z0)) ) ;

end

